@@ -1,3 +1,8 @@
+"""
+author: Sanjaya Lohani
+email: slohani@mlphys_nightly.com
+Licence: Apache-2.0
+"""
 import tensorflow as tf
 
 
